# Copyright (c) 2016 Rui Carmo
# Copyright (c) 2023-2025, Abilian SAS
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from ._setup import NginxVirtualHost

__all__ = ["NginxVirtualHost"]
