# Copyright (c) 2023-2025, Abilian SAS
#
# SPDX-License-Identifier: Apache-2.0
"""OS setup strategy plugins.

This package contains plugins for setting up hop3 on different operating systems.
Each OS plugin implements the OS protocol and can auto-detect
whether it matches the current system.
"""

from __future__ import annotations
